==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicIconFactory__24DummyIcon.h <==
// class javax.swing.plaf.basic.BasicIconFactory$DummyIcon

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34a201423793410e javax_swing_plaf_basic_BasicIconFactory__24DummyIcon

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon_H_
#define _JC_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicIconFactory__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *);
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$_init$c9bd4d2b19cc1361(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__241$object *);

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *);
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *);
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *);
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *);
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods	javax_swing_plaf_basic_BasicIconFactory__24DummyIcon;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs {
    _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs	javax_swing_plaf_basic_BasicIconFactory__24DummyIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs	javax_swing_plaf_basic_BasicIconFactory__24DummyIcon;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object {
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicIconFactory__24DummyIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicIconFactory__24DummyIcon.h <==
// class javax.swing.plaf.basic.BasicIconFactory$DummyIcon

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34a201423793410e javax_swing_plaf_basic_BasicIconFactory__24DummyIcon

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon_H_
#define _JC_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicIconFactory__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$_init$c9bd4d2b19cc1361(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *) _JC_JCNI_ATTR;
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *) _JC_JCNI_ATTR;
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vmethods	javax_swing_plaf_basic_BasicIconFactory__24DummyIcon;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs {
    _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_refs	javax_swing_plaf_basic_BasicIconFactory__24DummyIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$sub_nonrefs	javax_swing_plaf_basic_BasicIconFactory__24DummyIcon;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$object {
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$vtype _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicIconFactory__24DummyIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicIconFactory__24DummyIcon_H_ */
